@@ -154,20 +154,14 @@ class TelegramBotManager(LocaleMixin):
 
         self.logger.debug("Setting up Telegram bot updater...")
         self.updater: Updater = Updater(config['token'],
+                                        base_url=channel.flag('api_base_url'),
+                                        base_file_url=channel.flag('api_base_file_url'),
                                         request_kwargs=req_kwargs,
                                         use_context=True)
 
         if isinstance(config.get('webhook'), dict):
             self.logger.debug("Setting up webhook...")
             self.webhook = True
-            webhook_conf = config['webhook']
-            if webhook_conf.get('set_webhook'):
-                set_webhook = webhook_conf['set_webhook']
-                if set_webhook.get('certificate'):
-                    set_webhook['certificate'] = open(set_webhook['certificate'], 'rb')
-                self.logger.debug("Setting webhook URL...")
-                self.updater.bot.set_webhook(**set_webhook)
-                self.logger.debug("Webhook URL is set...")
             self.logger.debug("Webhook is set...")
 
         self.logger.debug("Checking connection to Telegram bot API...")
@@ -564,20 +558,21 @@ class TelegramBotManager(LocaleMixin):
     def set_chat_description(self, *args, **kwargs):
         return self.updater.bot.set_chat_description(*args, **kwargs)
 
-    def polling(self, clean: bool = False):
+    def polling(self, drop_pending_updates: bool = False):
         """
         Poll message from Telegram Bot API. Can be used to extend for web hook.
         This method must NOT be blocking.
 
         Args:
-            clean: Whether to clean any pending updates on Telegram servers
-                before actually starting to poll. Default is False.
+            drop_pending_updates: Whether to clean any pending updates on
+                Telegram servers before actually starting to poll.
+                Default is False.
         """
         if self.webhook:
             start_webhook = self.channel.config['webhook']['start_webhook']
             self.updater.start_webhook(**start_webhook)
         else:
-            self.updater.start_polling(timeout=10, clean=clean)
+            self.updater.start_polling(timeout=10, drop_pending_updates=drop_pending_updates)
 
     def graceful_stop(self):
         """Gracefully stop the bot"""
