@@ -48,6 +48,7 @@ class MasterMessageProcessor(LocaleMixin):
         TGMsgType.Photo: MsgType.Image,
         TGMsgType.Sticker: MsgType.Sticker,
         # TGMsgType.AnimatedSticker: MsgType.Animation,
+        TGMsgType.VideoSticker: MsgType.Animation,
         TGMsgType.Video: MsgType.Video,
         TGMsgType.VideoNote: MsgType.Video,
         TGMsgType.Voice: MsgType.Voice,
@@ -142,6 +143,7 @@ class MasterMessageProcessor(LocaleMixin):
 
         destination = None
         edited = None
+        quote = False
 
         if update.edited_message or update.edited_channel_post:
             self.logger.debug('[%s] Message is edited: %s', mid, message.edit_date)
@@ -151,10 +153,14 @@ class MasterMessageProcessor(LocaleMixin):
                 return
             destination = msg_log.slave_origin_uid
             edited = msg_log
+            quote = msg_log.build_etm_msg(self.chat_manager).target is not None
 
         if destination is None:
-            # if the chat is singly-linked
             destination = self.get_singly_linked_chat_id_str(update.effective_chat)
+            if destination:
+                # if the chat is singly-linked
+                quote = message.reply_to_message is not None
+                self.logger.debug("[%s] Chat %s is singly-linked to %s", mid, message.chat, destination)
 
         if destination is None:  # not singly linked
             quote = False
@@ -177,9 +183,6 @@ class MasterMessageProcessor(LocaleMixin):
                 self.logger.debug("[%s] Cached destination found: %s", mid, cached_dest)
                 destination = cached_dest
                 self._send_cached_chat_warning(update, TelegramChatID(message.chat.id), cached_dest)
-        else:
-            quote = message.reply_to_message is not None
-            self.logger.debug("[%s] Chat %s is singly-linked to %s", mid, message.chat, destination)
 
         self.logger.debug("[%s] Destination chat = %s", mid, destination)
 
@@ -251,6 +254,7 @@ class MasterMessageProcessor(LocaleMixin):
                 self.logger.debug("[%s] EFB message type: %s", message_id, mtype)
             else:
                 self.logger.info("[%s] Message type %s is not supported by ETM", message_id, mtype)
+                log_message = False
                 raise EFBMessageTypeNotSupported(
                     self._("{type_name} messages are not supported by EFB Telegram Master channel.")
                         .format(type_name=mtype.name))
@@ -313,7 +317,7 @@ class MasterMessageProcessor(LocaleMixin):
                     self.logger.debug("[%s] Message media is edited (%s -> %s)", m.uid, edited.file_unique_id, m.file_unique_id)
                     m.edit_media = True
 
-            # Enclose message as an Message object by message type.
+            # Enclose message as a Message object by message type.
             if mtype is TGMsgType.Text:
                 m.text = msg_md_text
             elif mtype is TGMsgType.Photo:
@@ -330,10 +334,20 @@ class MasterMessageProcessor(LocaleMixin):
                 assert message.animation
                 m.text = msg_md_caption
                 self.logger.debug("[%s] Telegram message is a \"Telegram GIF\".", message_id)
-                m.filename = getattr(message.animation, "file_name", None) or None
-                if m.filename and not m.filename.lower().endswith(".gif"):
-                    m.filename += ".gif"
+                m_filename = getattr(message.animation, "file_name", None) or None
+                if m_filename and not m_filename.lower().endswith(".gif"):
+                    m_filename += ".gif"
+                m.filename = m_filename
                 m.mime = message.animation.mime_type or m.mime
+            elif mtype is TGMsgType.VideoSticker:
+                assert message.sticker and message.sticker.is_video
+                m.text = msg_md_caption
+                self.logger.debug("[%s] Telegram message is a WebM sticker.", message_id)
+                m_filename = getattr(message.sticker, "file_name", None) or "sticker"
+                if m_filename and not m_filename.lower().endswith(".gif"):
+                    m_filename += ".gif"
+                m.filename = m_filename
+                m.mime = "image/gif"
             elif mtype is TGMsgType.Document:
                 assert message.document
                 m.text = msg_md_caption
@@ -471,7 +485,7 @@ class MasterMessageProcessor(LocaleMixin):
 
     def _check_file_download(self, file_obj: Any):
         """
-        Check if the file is available for download..
+        Check if the file is available for download.
 
         Args:
             file_obj (telegram.File): PTB file object
@@ -480,7 +494,8 @@ class MasterMessageProcessor(LocaleMixin):
             EFBMessageError: When file exceeds the maximum download size.
         """
         size = getattr(file_obj, "file_size", None)
-        if size and size > MAX_FILESIZE_DOWNLOAD:
+        if size and not self.channel.flag("local_tdlib_api")\
+                and size > MAX_FILESIZE_DOWNLOAD:
             size_str = humanize.naturalsize(size)
             max_size_str = humanize.naturalsize(MAX_FILESIZE_DOWNLOAD)
             raise EFBMessageError(
