@@ -52,12 +52,15 @@ class ExperimentalFlagsManager(LocaleMixin):
         "animated_stickers": False,
         "send_to_last_chat": "warn",
         "default_media_prompt": "emoji",
+        "api_base_url": None,
+        "api_base_file_url": None,
+        "local_tdlib_api": False,
     }
 
     def __init__(self, channel: 'TelegramChannel'):
         self.channel = channel
         self.config: Dict[str, Any] = ExperimentalFlagsManager.DEFAULT_VALUES.copy()
-        self.config.update(channel.config.get('flags', dict()))
+        self.config.update(channel.config.get('flags', dict()) or dict())
 
     def __call__(self, flag_key: str) -> Any:
         if flag_key not in self.config:
